/*
    module/xxx.c
    virtual driver for using RTL timing sources

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1999 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/


#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/mm.h>
#include <linux/malloc.h>
#include <linux/errno.h>
#include <linux/ioport.h>
#include <linux/delay.h>
#include <linux/interrupt.h>
#include <linux/timex.h>
#include <linux/timer.h>
#include <asm/io.h>
#include <comedi_module.h>


comedi_devinit xxx_init;
static int xxx_rem(comedi_device *dev);
#if 0
static void xxx_interrupt(int irq,void *dev,struct pt_regs * regs);
#endif

typedef struct{
	int device;
	int subd;
	comedi_device *dev;
	comedi_subdevice *s;
}xxx_private;
#define devpriv ((xxx_private *)dev->private)


static int xxx_ai_mode0(comedi_device *dev,comedi_subdevice *s,comedi_trig *it)
{
	return comedi_trig_ioctl(devpriv->device,devpriv->subd,it);
}

static int xxx_ai_mode1(comedi_device *dev,comedi_subdevice *s,comedi_trig *it)
{
	return -EINVAL;
}

static int xxx_ai_mode2(comedi_device *dev,comedi_subdevice *s,comedi_trig *it)
{
	return -EINVAL;
}

int xxx_init(comedi_device *dev,comedi_devconfig *it)
{
	int ret;
	comedi_subdevice *s;

	if(strcmp("xxx",it->board_name))
		return 0;

	printk("comedi%d: xxx: ",dev->minor);
	dev->board_name="xxx";
	dev->driver_name="xxx";

	dev->n_subdevices=1;
	if((ret=alloc_subdevices(dev))<0)
		return ret;
	if((ret=alloc_private(dev,sizeof(xxx_private)))<0)
		return ret;

	devpriv->device=it->options[0];
	devpriv->subd=it->options[1];

	ret=comedi_lock_ioctl(devpriv->device,devpriv->subd);
	if(ret<0)
		goto cleanup;

	devpriv->dev=comedi_devices+devpriv->device;
	devpriv->s=devpriv->dev->subdevices+devpriv->subd;

	s=dev->subdevices+0;
	s->type=COMEDI_SUBD_AI;
	s->subdev_flags=SDF_READABLE|SDF_RT;
	s->n_chan=devpriv->s->n_chan;
	s->len_chanlist=1024;
	s->trig[0]=xxx_ai_mode0;
	s->trig[1]=xxx_ai_mode1;
	s->trig[2]=xxx_ai_mode2;
	s->maxdata=devpriv->s->maxdata;
	s->range_type=devpriv->s->range_type;
	s->timer_type=0;		/* XXX */

	dev->rem=xxx_rem;

	return 1;

cleanup:
	return ret;
}


static int xxx_rem(comedi_device *dev)
{
	printk("comedi%d: xxx: remove\n",dev->minor);
	
	kfree(dev->private);
	kfree(dev->subdevices);

	return 0;
}


